fsdir

package module
v0.0.0-...-1588cfd Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 7, 2025 License: MIT Imports: 2 Imported by: 1

README

go-fsdir

Package fsdir provides tools for working with "io/fs" directories, for the Go programming language.

Documention

Online documentation, which includes examples, can be found at: http://godoc.org/codeberg.org/reiver/go-fsdir

GoDoc

Import

To import package fsdir use import code like the following:

import "codeberg.org/reiver/go-fsdir"

Installation

To install package fsdir do the following:

GOPROXY=direct go get codeberg.org/reiver/go-fsdir

Author

Package fsdir was written by Charles Iliya Krempeaux

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func FileIsDir

func FileIsDir(file fs.File) (bool, error)

FileIsDir returns whether an fs.File is a directory or not.

func ReadAllDir

func ReadAllDir(file fs.File) ([]fs.DirEntry, error)

If the passed fs.File is a directory, then ReadAllDir return all of its fs.DirEntry if it fits the DirReaderAll or fs.ReadDirFile interfaces.

Types

type DirReaderAll

type DirReaderAll interface {
	ReadAllDir() ([]fs.DirEntry, error)
}

DirReaderAll provides a simplified and state-less way get reading all the entries in a directory.

Jump to